using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;


namespace GroupLab.Phidgets.Demos
{
	/// <summary>
	/// Author: Saul Greenberg, Feb 4 2005
	/// rfidSimple provides a very simple GUI that illustrates the 
	/// basic use of the rfid component. 
	/// -the attached/detached state is shown in the title bar
	/// -if it is version 2 of the hardware (which has outputs), the reader is turned on
	/// -tags seen are added to the top of the list everytime a tag is read ;
	///  this included multiple reads of the same tag. 
	/// -The onboard LED (for Version 2 only) is toggled after every tag read.
	/// </summary>
	public class rfidSimple : System.Windows.Forms.Form
	{
		private GroupLab.Phidgets.RFID rfid1;
		private System.Windows.Forms.ListBox listBox1;
		private System.ComponentModel.Container components = null;

		public rfidSimple()
		{
			InitializeComponent();
		}

		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.rfid1 = new GroupLab.Phidgets.RFID();
			this.listBox1 = new System.Windows.Forms.ListBox();
			this.SuspendLayout();
			// 
			// rfid1
			// 
			this.rfid1.AutoAttach = true;
			this.rfid1.PhidgetDevice = null;
			this.rfid1.Attach += new System.EventHandler(this.rfid1_Attach);
			this.rfid1.Tag += new GroupLab.Phidgets.RFIDTagEventHandler(this.rfid1_Tag);
			this.rfid1.Detach += new System.EventHandler(this.rfid1_Detach);
			// 
			// listBox1
			// 
			this.listBox1.Dock = System.Windows.Forms.DockStyle.Fill;
			this.listBox1.Location = new System.Drawing.Point(0, 0);
			this.listBox1.Name = "listBox1";
			this.listBox1.Size = new System.Drawing.Size(292, 264);
			this.listBox1.TabIndex = 0;
			// 
			// rfidSimple
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(292, 266);
			this.Controls.Add(this.listBox1);
			this.Name = "rfidSimple";
			this.Text = "rfidSimple -- Dettached";
			this.ResumeLayout(false);

		}
		#endregion

		// When the reader is atttached, change the title bar to indicate it 
		// Version 2 of the rfid hardware has the ability to be turned
		// on and off (via Output 3). Make sure it is on, as the default is off		
		private void rfid1_Attach(object sender, System.EventArgs e)
		{
			this.Text = "rfidSimple -- Attached";
			if (rfid1.Outputs.Count >=3) 
				rfid1.Outputs[3].State = true;
		}

		// When the reader is detached, change the title bar to indicate it 
		private void rfid1_Detach(object sender, System.EventArgs e)
		{
			this.Text = "rfidSimple -- Detached";
		}

		// When a tag is read, add it to the top of the listbox (including duplicates)
		// If we are using version 2 of the RFID hardware, 
		// toggle the on-board LED. This is just to show that we can do it....
		int i = 0;
		private void rfid1_Tag(object sender, GroupLab.Phidgets.RFIDTagEventArgs e)
		{
			listBox1.Items.Insert (0, e.Tag.ToString ());
			if (rfid1.Outputs.Count >= 3)	// outputs only availabe in version 2
				rfid1.Outputs[2].State = !rfid1.Outputs[2].State;
		}
	}
}
